@@ -6,22 +6,16 @@
 #     http://doc.scrapy.org/topics/settings.html
 #
 
-import sys
-import os.path
+import os
 
 PROJECT_ROOT = os.path.abspath(os.path.dirname(__file__))
-sys.path = sys.path + [os.path.join(PROJECT_ROOT, '../../..'), os.path.join(PROJECT_ROOT, '../..')]
-
-from django.core.management import setup_environ
-import example_project.settings
-setup_environ(example_project.settings)
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "example_project.settings")
 
 
 BOT_NAME = 'open_news'
-BOT_VERSION = '1.0'
 
 SPIDER_MODULES = ['dynamic_scraper.spiders', 'open_news.scraper',]
-USER_AGENT = '%s/%s' % (BOT_NAME, BOT_VERSION)
+USER_AGENT = '%s/%s' % (BOT_NAME, '1.0')
 
 ITEM_PIPELINES = [
     'dynamic_scraper.pipelines.DjangoImagesPipeline',
